@@ -23,6 +23,8 @@ import json
 import traceback
 from datetime import datetime
 from dateutil import parser
+import gi
+gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 _ = gettext.gettext
 
@@ -75,14 +77,24 @@ def load_from_docinfo(meta, doc):
         traceback.print_exc()
 
 
-def merge(metadata, input_files):
-    """ Merge current global metadata and each imported files meta data """
+def _safeiter(elements):
+    it = iter(elements)
+    while True:
+        try:
+            yield next(it)
+        except StopIteration:
+            break
+        except ValueError:
+            traceback.print_exc()
+
+
+def merge_doc(metadata, input_docs):
+    """Same as merge but with pikepdf.PDF object instead of files"""
     r = metadata.copy()
-    for p in input_files:
-        doc = pikepdf.open(p.copyname, password=p.password)
+    for doc in input_docs:
         with doc.open_metadata() as meta:
             load_from_docinfo(meta, doc)
-            for k, v in meta.items():
+            for k, v in _safeiter(meta.items()):
                 if not _pikepdf_meta_is_valid(v):
                     # workaround for https://github.com/pikepdf/pikepdf/issues/84
                     del meta[k]
@@ -91,6 +103,12 @@ def merge(metadata, input_files):
     return r
 
 
+def merge(metadata, input_files):
+    """Merge current global metadata and each imported files meta data"""
+    docs = [pikepdf.open(copyname, password=password) for copyname, password in input_files]
+    return merge_doc(metadata, docs)
+
+
 def _metatostr(value, name):
     """ Convert a meta data value from list to string if it's not a string """
     if isinstance(value, str):
@@ -141,7 +159,8 @@ class _EditedEventHandler(object):
     def editable_changed(self, editable):
         self.new_text = editable.get_text()
 
-    def _parse_date(self, string, parent):
+    @staticmethod
+    def _parse_date(string, parent):
         try:
             date = parser.parse(string)
             return datetime.isoformat(date) # ISO-8601 formatted date
@@ -179,9 +198,10 @@ def edit(metadata, pdffiles, parent):
     dialog = Gtk.Dialog(title=_('Edit properties'),
                         parent=parent,
                         flags=Gtk.DialogFlags.MODAL,
-                        buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-                                 Gtk.STOCK_OK, Gtk.ResponseType.OK))
-    dialog.set_default_response(Gtk.ResponseType.OK)
+                        buttons=("_Cancel", Gtk.ResponseType.CANCEL,
+                                 "_OK", Gtk.ResponseType.OK))
+    ok_button = dialog.get_widget_for_response(response_id = Gtk.ResponseType.OK)
+    ok_button.grab_focus()
     # Property, Value, XMP name (hidden)
     liststore = Gtk.ListStore(str, str, str)
     mergedmetadata = merge(metadata, pdffiles)
